==> 0.7.1.zip: grichelde/localisation/deDE.lua <==
local L = LibStub('AceLocale-3.0'):NewLocale('Grichelde', 'deDE')
if not L then return end

-- system messages
L.AddonName = "Grichelde"
L.VersionAbbr = "v"
L.AddonLoaded = "%s hilft Euch jetzt bei euren Sprachschwierigkeiten."
L.Upgrade_ToVersion = "Hebe Databank auf Version %s an."
L.Upgrade_Successful = "Upgrade erfolgreich."
L.Debug_Options = "Optionen"
L.Debug_Mappings = "Ersetzungen"
L.Debug_Mappings_Found = "%d Ersetzungen gefunden"

-- profiles
L.Profiles_Available = "Verf\195\188gbare Profile:"
L.Profiles_Created = "Neues Profil %s angelegt."
L.Profiles_Loaded = "Profil %s geladen."
L.Profiles_Refreshed = "Profil %s aktualisiert."
L.Profiles_Deleted = "Profil %s gel\195\182scht."
L.Profiles_Copied = "Einstellungen von Profil %s \195\188bernommen."
L.Profiles_Reset = "Profil %s zur\195\188ckgesetzt."
L.Profiles_Invalid = "Ung\195\188ltiges Profil %s!"
L.Profiles_DeleteError = "Das aktive Profil kann nicht gel\195\182scht werden!"

-- options
L.Options_Title = "%s Einstellungen"
L.Options_Enabled_Name = "Aktiv"
L.Options_Enabled_Desc = "Aktiviert %s"

L.Options_Channels_Group_Name = "Kan\195\164le"
L.Options_Channels_Group_Desc = "%s ist in folgenden Kan\195\164len aktiv."
L.Options_Channels_Header = "Eine Ersetzung wird nur in den unten markierten Kan\195\164len durchgef\195\188hrt:"

L.Options_Channel_Say_Name = "Sagen"
L.Options_Channel_Say_Desc = "Aktiviert %s im Kanal \"Sagen\"."
L.Options_Channel_Emote_Name = "Emote"
L.Options_Channel_Emote_Desc = "Aktiviert %s im Kanal \"Emote\"."
L.Options_Channel_Yell_Name = "Schreien"
L.Options_Channel_Yell_Desc = "Aktiviert %s im Kanal \"Schreien\"."
L.Options_Channel_Party_Name = "Gruppe"
L.Options_Channel_Party_Desc = "Aktiviert %s im Kanal \"Gruppe\"."
L.Options_Channel_PartyLeader_Name = "Gruppenanf\195\188hrer"
L.Options_Channel_PartyLeader_Desc = "Aktiviert %s im Kanal \"Gruppenanf\195\188hrer\"."
L.Options_Channel_Guild_Name = "Gilde"
L.Options_Channel_Guild_Desc = "Aktiviert %s im Kanal \"Gilde\"."
L.Options_Channel_Officer_Name = "Offiziere"
L.Options_Channel_Officer_Desc = "Aktiviert %s im Kanal \"Offiziere\"."
L.Options_Channel_Raid_Name = "Schlachtzug"
L.Options_Channel_Raid_Desc = "Aktiviert %s im Kanal \"Schlachtzug\"."
L.Options_Channel_RaidLeader_Name = "Schlachtzugsanf\195\188hrer"
L.Options_Channel_RaidLeader_Desc = "Aktiviert %s im Kanal \"Schlachtzugsanf\195\188hrer\"."
L.Options_Channel_RaidWarning_Name = "Schlachtzugswarnung"
L.Options_Channel_RaidWarning_Desc = "Aktiviert %s im Kanal \"Schlachtzugswarnung."
L.Options_Channel_Instance_Name = "Instanz"
L.Options_Channel_Instance_Desc = "Aktiviert %s im Kanal \"Instanz\"."
L.Options_Channel_Battleground_Name = "Schlachtfeld"
L.Options_Channel_Battleground_Desc = "Aktiviert %s im Kanal \"Schlachtfeld\"."
L.Options_Channel_Whisper_Name = "Fl\195\188stern"
L.Options_Channel_Whisper_Desc = "Aktiviert %s im Kanal \"Fl\195\188stern\"."

L.Options_Replacements_Group_Name = "Ersetzungen"
L.Options_Replacements_Group_Desc = "Diese Vorkommen werden in den aktivierten Kan\195\164len ersetzt."
L.Options_Replacements_Add_Name = "Hinzu"
L.Options_Replacements_Add_Desc = "F\195\188gt eine neue Zuordnung hinzu."
L.Options_Replacements_DeleteAll_Name = "Alle L\195\182schen"
L.Options_Replacements_DeleteAll_Desc = "L\195\182scht alle Zuweisungen."
L.Options_Replacements_DeleteAll_ConfirmText="Wirklich ALLE Zuweisungen l\195\182schen?"
L.Options_Replacements_Header = "Die Vorkommen links vom Pfeil ( => ) werden in den aktivierten Kan\195\164len gesucht und durch den Text rechts vom Pfeil ersetzt."
                                .."|nWird die Gro\195\159- und Kleinschreibung ignoriert, wird die Gro\195\159schreibung jedes Zeichens wird bei der Ersetzung \195\188bernommen."
                                .."|nDas Zusammenfassen aufeinanderfolgender Treffer vermeidet unsch\195\182ne Wiederholungen, die durch die Ersetzung entstehen k\195\182nnen."
                                .."|nMit den beiden Standard-Ersetzung wird so aus \"Tasse\" => \"Ckache\"."
L.Options_Mapping_Group_Name = "%s => %s"
L.Options_Mapping_Group_Desc = "Dieses Vorkommen wird in den aktivierten Kan\195\164len ersetzt."
L.Options_Mapping_EmptyMapping = "(keine)"
L.Options_Mapping_SearchText_Name = "Suchtext:"
L.Options_Mapping_SearchText_Desc = "Dieser Text wird in der Chateingabe gesucht."
L.Options_Mapping_ReplaceText_Name = "Ersetzung:"
L.Options_Mapping_ReplaceText_Desc = "Jeder Suchtreffer wird mit diesem Text ersetzt."
L.Options_Mapping_ExactCase_Name = "exakte Gro\195\159- und Kleinschreibung"
L.Options_Mapping_ExactCase_Desc = "Wenn gesetzt, muss die Gro\195\159- und Kleinschreibung des Suchtextes exakt \195\188berein stimmen. Anderfalls wird die Gro\195\159schreibung jedes Zeichens bei der Ersetzung \195\188bernommen."
L.Options_Mapping_Consolidate_Name = "Fa\195\159e aufeinanderfolgende Treffer zusammen"
L.Options_Mapping_Consolidate_Desc = "Wenn durch die Ersetzung die Zeichenfolge mehrfach hintereinander steht,|nfasse sie zu einem Vorkommen zusammen."
L.Options_Mapping_MoveUp_Name = "^"
L.Options_Mapping_MoveUp_Desc = "nach oben verschieben"
L.Options_Mapping_MoveDown_Name = "v"
L.Options_Mapping_MoveDown_Desc = "nach unten verschieben"
L.Options_Mapping_Delete_Name = "L\195\182schen"
L.Options_Mapping_Delete_Desc = "L\195\182scht diese Zuweisung."
L.Options_Mapping_Delete_ConfirmText="Diese Zuweisung l\195\182schen?"

==> 0.7.2.zip: grichelde/localisation/deDE.lua <==
local L = LibStub('AceLocale-3.0'):NewLocale('Grichelde', 'deDE')
if not L then return end

-- system messages
L.AddonName = "Grichelde"
L.VersionAbbr = "v"
L.AddonLoaded = "%s hilft Euch jetzt bei euren Sprachschwierigkeiten."
L.Upgrade_ToVersion = "Hebe Databank auf Version %s an."
L.Upgrade_Successful = "Upgrade erfolgreich."
L.Debug_Options = "Optionen"
L.Debug_Mappings = "Ersetzungen"
L.Debug_Mappings_Hint = "Der Inhalt der Textbox dient nur zur Fehlersuche und kann herauskopiert werden. Es werden keine Werte aus dieser Textbox eingelesen oder anderweitig verwertet."
L.Debug_Mappings_Found = "%d Ersetzungen gefunden"
L.Debug_Profile = "Profil"

-- profiles
L.Profiles_Available = "Verf\195\188gbare Profile:"
L.Profiles_Created = "Neues Profil %s angelegt."
L.Profiles_Loaded = "Profil %s geladen."
L.Profiles_Refreshed = "Profil %s aktualisiert."
L.Profiles_Deleted = "Profil %s gel\195\182scht."
L.Profiles_Copied = "Einstellungen von Profil %s \195\188bernommen."
L.Profiles_Reset = "Profil %s zur\195\188ckgesetzt."
L.Profiles_Invalid = "Ung\195\188ltiges Profil %s!"
L.Profiles_DeleteError = "Das aktive Profil kann nicht gel\195\182scht werden!"

-- options
L.Options_Title = "%s Einstellungen"
L.Options_Enabled_Name = "Aktiv"
L.Options_Enabled_Desc = "Aktiviert %s"
L.Options_Minimap_Button_Name = "Zeige Minimap-Knopf"
L.Options_Minimap_Button_Desc = "Zeigt oder versteckt den Knopf an der Miniaturkarte"
L.Options_Minimap_Tooltip_Options_Left = "Linksklick"
L.Options_Minimap_Tooltip_Options_Right = "\195\150ffnet oder schlie\195\159t die Einstellungen."
L.Options_Minimap_Tooltip_Mappings_Left = "Rechtsklick"
L.Options_Minimap_Tooltip_Mappings_Right = "\195\150ffnet das Debug-Fenster mit Ersetzungscode."

L.Options_Channels_Group_Name = "Kan\195\164le"
L.Options_Channels_Group_Desc = "%s ist in folgenden Kan\195\164len aktiv."
L.Options_Channels_Header = "Eine Ersetzung wird nur in den unten markierten Kan\195\164len durchgef\195\188hrt:"

L.Options_Channel_Say_Name = "Sagen"
L.Options_Channel_Say_Desc = "Aktiviert %s im Kanal \"Sagen\"."
L.Options_Channel_Emote_Name = "Emote"
L.Options_Channel_Emote_Desc = "Aktiviert %s im Kanal \"Emote\"."
L.Options_Channel_Yell_Name = "Schreien"
L.Options_Channel_Yell_Desc = "Aktiviert %s im Kanal \"Schreien\"."
L.Options_Channel_Party_Name = "Gruppe"
L.Options_Channel_Party_Desc = "Aktiviert %s im Kanal \"Gruppe\"."
L.Options_Channel_PartyLeader_Name = "Gruppenanf\195\188hrer"
L.Options_Channel_PartyLeader_Desc = "Aktiviert %s im Kanal \"Gruppenanf\195\188hrer\"."
L.Options_Channel_Guild_Name = "Gilde"
L.Options_Channel_Guild_Desc = "Aktiviert %s im Kanal \"Gilde\"."
L.Options_Channel_Officer_Name = "Offiziere"
L.Options_Channel_Officer_Desc = "Aktiviert %s im Kanal \"Offiziere\"."
L.Options_Channel_Raid_Name = "Schlachtzug"
L.Options_Channel_Raid_Desc = "Aktiviert %s im Kanal \"Schlachtzug\"."
L.Options_Channel_RaidLeader_Name = "Schlachtzugsanf\195\188hrer"
L.Options_Channel_RaidLeader_Desc = "Aktiviert %s im Kanal \"Schlachtzugsanf\195\188hrer\"."
L.Options_Channel_RaidWarning_Name = "Schlachtzugswarnung"
L.Options_Channel_RaidWarning_Desc = "Aktiviert %s im Kanal \"Schlachtzugswarnung."
L.Options_Channel_Instance_Name = "Instanz"
L.Options_Channel_Instance_Desc = "Aktiviert %s im Kanal \"Instanz\"."
L.Options_Channel_Battleground_Name = "Schlachtfeld"
L.Options_Channel_Battleground_Desc = "Aktiviert %s im Kanal \"Schlachtfeld\"."
L.Options_Channel_Whisper_Name = "Fl\195\188stern"
L.Options_Channel_Whisper_Desc = "Aktiviert %s im Kanal \"Fl\195\188stern\"."

L.Options_Replacements_Group_Name = "Ersetzungen"
L.Options_Replacements_Group_Desc = "Diese Vorkommen werden in den aktivierten Kan\195\164len ersetzt."
L.Options_Replacements_Add_Name = "Hinzu"
L.Options_Replacements_Add_Desc = "F\195\188gt eine neue Zuordnung hinzu."
L.Options_Replacements_DeleteAll_Name = "Alle L\195\182schen"
L.Options_Replacements_DeleteAll_Desc = "L\195\182scht alle Zuweisungen."
L.Options_Replacements_DeleteAll_ConfirmText="Wirklich ALLE Zuweisungen l\195\182schen?"
L.Options_Replacements_Header = "Die Vorkommen links vom Pfeil ( => ) werden in den aktivierten Kan\195\164len gesucht und durch den Text rechts vom Pfeil ersetzt."
                                .."|nWird die Gro\195\159- und Kleinschreibung ignoriert, wird die Gro\195\159schreibung jedes Zeichens bei der Ersetzung \195\188bernommen."
                                .."|nDas Zusammenfassen aufeinanderfolgender Treffer vermeidet unsch\195\182ne Wiederholungen, die durch die Ersetzung entstehen k\195\182nnen."
                                .."|nMit den beiden Standard-Ersetzung wird so aus \"Tasse\" => \"Ckache\"."
L.Options_Mapping_Group_Name = "%s => %s"
L.Options_Mapping_Group_Desc = "Dieses Vorkommen wird in den aktivierten Kan\195\164len ersetzt."
L.Options_Mapping_EmptyMapping = "(keine)"
L.Options_Mapping_SearchText_Name = "Suchtext:"
L.Options_Mapping_SearchText_Desc = "Dieser Text wird in der Chateingabe gesucht."
L.Options_Mapping_ReplaceText_Name = "Ersetzung:"
L.Options_Mapping_ReplaceText_Desc = "Jeder Suchtreffer wird mit diesem Text ersetzt."
L.Options_Mapping_ExactCase_Name = "Exakte Gro\195\159- und Kleinschreibung"
L.Options_Mapping_ExactCase_Desc = "Wenn gesetzt, muss die Gro\195\159- und Kleinschreibung des Suchtextes exakt \195\188berein stimmen. Anderfalls wird die Gro\195\159schreibung jedes Zeichens bei der Ersetzung \195\188bernommen."
L.Options_Mapping_Consolidate_Name = "Fasse aufeinanderfolgende Treffer zusammen"
L.Options_Mapping_Consolidate_Desc = "Wenn durch die Ersetzung die Zeichenfolge mehrfach hintereinander steht,|nfasse sie zu einem Vorkommen zusammen."
L.Options_Mapping_MoveUp_Name = "^"
L.Options_Mapping_MoveUp_Desc = "nach oben verschieben"
L.Options_Mapping_MoveDown_Name = "v"
L.Options_Mapping_MoveDown_Desc = "nach unten verschieben"
L.Options_Mapping_Delete_Name = "L\195\182schen"
L.Options_Mapping_Delete_Desc = "L\195\182scht diese Zuweisung."
L.Options_Mapping_Delete_ConfirmText="Diese Zuweisung l\195\182schen?"
